/ /   C o p y r i g h t   ( C )   2 0 0 4 - 2 0 0 7   M y S Q L   A B 
 
 / / 
 
 / /   T h i s   p r o g r a m   i s   f r e e   s o f t w a r e ;   y o u   c a n   r e d i s t r i b u t e   i t   a n d / o r   m o d i f y 
 
 / /   i t   u n d e r   t h e   t e r m s   o f   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e   v e r s i o n   2   a s   p u b l i s h e d   b y 
 
 / /   t h e   F r e e   S o f t w a r e   F o u n d a t i o n 
 
 / / 
 
 / /   T h e r e   a r e   s p e c i a l   e x c e p t i o n s   t o   t h e   t e r m s   a n d   c o n d i t i o n s   o f   t h e   G P L   
 
 / /   a s   i t   i s   a p p l i e d   t o   t h i s   s o f t w a r e .   V i e w   t h e   f u l l   t e x t   o f   t h e   
 
 / /   e x c e p t i o n   i n   f i l e   E X C E P T I O N S   i n   t h e   d i r e c t o r y   o f   t h i s   s o f t w a r e   
 
 / /   d i s t r i b u t i o n . 
 
 / / 
 
 / /   T h i s   p r o g r a m   i s   d i s t r i b u t e d   i n   t h e   h o p e   t h a t   i t   w i l l   b e   u s e f u l , 
 
 / /   b u t   W I T H O U T   A N Y   W A R R A N T Y ;   w i t h o u t   e v e n   t h e   i m p l i e d   w a r r a n t y   o f 
 
 / /   M E R C H A N T A B I L I T Y   o r   F I T N E S S   F O R   A   P A R T I C U L A R   P U R P O S E .     S e e   t h e 
 
 / /   G N U   G e n e r a l   P u b l i c   L i c e n s e   f o r   m o r e   d e t a i l s . 
 
 / / 
 
 / /   Y o u   s h o u l d   h a v e   r e c e i v e d   a   c o p y   o f   t h e   G N U   G e n e r a l   P u b l i c   L i c e n s e 
 
 / /   a l o n g   w i t h   t h i s   p r o g r a m ;   i f   n o t ,   w r i t e   t o   t h e   F r e e   S o f t w a r e 
 
 / /   F o u n d a t i o n ,   I n c . ,   5 9   T e m p l e   P l a c e ,   S u i t e   3 3 0 ,   B o s t o n ,   M A     0 2 1 1 1 - 1 3 0 7     U S A   
 
 u s i n g   S y s t e m ; 
 
 u s i n g   S y s t e m . D a t a ; 
 
 u s i n g   S y s t e m . T h r e a d i n g ; 
 
 u s i n g   M y S q l . D a t a . M y S q l C l i e n t ; 
 
 u s i n g   M b U n i t . F r a m e w o r k ; 
 
 u s i n g   S y s t e m . R e f l e c t i o n ; 
 
 u s i n g   S y s t e m . C o l l e c t i o n s ; 
 
 u s i n g   S y s t e m . C o l l e c t i o n s . G e n e r i c ; 
 
 
 
 n a m e s p a c e   M y S q l . D a t a . M y S q l C l i e n t . T e s t s 
 
 { 
 
 	 / / /   < s u m m a r y > 
 
 	 / / /   S u m m a r y   d e s c r i p t i o n   f o r   P o o l i n g T e s t s . 
 
 	 / / /   < / s u m m a r y > 
 
 	 [ T e s t F i x t u r e ] 
 
 	 p u b l i c   c l a s s   P o o l i n g T e s t s   :   B a s e T e s t 
 
 	 { 
 
 	 	 [ T e s t F i x t u r e S e t U p ] 
 
 	 	 p u b l i c   o v e r r i d e   v o i d   F i x t u r e S e t u p ( ) 
 
 	 	 { 
 
 	 	 	 c s A d d i t i o n s   =   " ; p o o l i n g = t r u e ;   c o n n e c t i o n   r e s e t = t r u e ; " ; 
 
 	 	 	 b a s e . F i x t u r e S e t u p ( ) ; 
 
 	 	 } 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   C o n n e c t i o n ( ) 
 
 	 	 { 
 
 	 	 	 s t r i n g   c o n n S t r   =   c o n n . C o n n e c t i o n S t r i n g   +   " ; p o o l i n g = t r u e " ; 
 
 
 
 	 	 	 M y S q l C o n n e c t i o n   c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 i n t   s e r v e r T h r e a d   =   c . S e r v e r T h r e a d ; 
 
 	 	 	 c . C l o s e ( ) ; 
 
 
 
 	 	 	 / /   f i r s t   t e s t   t h a t   o n l y   a   s i n g l e   c o n n e c t i o n   g e t ' s   u s e d 
 
 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   1 0 ;   i + + ) 
 
 	 	 	 { 
 
 	 	 	 	 c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 	 A s s e r t . A r e E q u a l ( s e r v e r T h r e a d ,   c . S e r v e r T h r e a d ) ; 
 
 	 	 	 	 c . C l o s e ( ) ; 
 
 	 	 	 } 
 
 
 
 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 K i l l C o n n e c t i o n ( c ) ; 
 
 	 	 	 c . C l o s e ( ) ; 
 
 
 
 	 	 	 c o n n S t r   + =   " ; M i n   P o o l   S i z e = 1 0 " ; 
 
 	 	 	 M y S q l C o n n e c t i o n [ ]   c o n n A r r a y   =   n e w   M y S q l C o n n e c t i o n [ 1 0 ] ; 
 
 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   c o n n A r r a y . L e n g t h ;   i + + ) 
 
 	 	 	 { 
 
 	 	 	 	 c o n n A r r a y [ i ]   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c o n n A r r a y [ i ] . O p e n ( ) ; 
 
 	 	 	 } 
 
 
 
 	 	 	 / /   n o w   m a k e   s u r e   a l l   t h e   s e r v e r   i d s   a r e   d i f f e r e n t 
 
 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   c o n n A r r a y . L e n g t h ;   i + + ) 
 
 	 	 	 { 
 
 	 	 	 	 f o r   ( i n t   j   =   0 ;   j   <   c o n n A r r a y . L e n g t h ;   j + + ) 
 
 	 	 	 	 { 
 
 	 	 	 	 	 i f   ( i   ! =   j ) 
 
 	 	 	 	 	 	 A s s e r t . I s T r u e ( c o n n A r r a y [ i ] . S e r v e r T h r e a d   ! =   c o n n A r r a y [ j ] . S e r v e r T h r e a d ) ; 
 
 	 	 	 	 } 
 
 	 	 	 } 
 
 
 
 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   c o n n A r r a y . L e n g t h ;   i + + ) 
 
 	 	 	 { 
 
 	 	 	 	 K i l l C o n n e c t i o n ( c o n n A r r a y [ i ] ) ; 
 
 	 	 	 	 c o n n A r r a y [ i ] . C l o s e ( ) ; 
 
 	 	 	 } 
 
 	 	 } 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   O p e n K i l l e d ( ) 
 
 	 	 { 
 
 	 	 	 t r y 
 
 	 	 	 { 
 
 	 	 	 	 s t r i n g   c o n n S t r   =   c o n n . C o n n e c t i o n S t r i n g   +   " ; p o o l i n g = t r u e ; m i n   p o o l   s i z e = 1 ;   m a x   p o o l   s i z e = 1 " ; 
 
 	 	 	 	 M y S q l C o n n e c t i o n   c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 	 i n t   t h r e a d I d   =   c . S e r v e r T h r e a d ; 
 
 	 	 	 	 / /   t h r e a d   g e t s   k i l l e d   r i g h t   h e r e 
 
 	 	 	 	 K i l l C o n n e c t i o n ( c ) ; 
 
 	 	 	 	 c . C l o s e ( ) ; 
 
 
 
 	 	 	 	 c . D i s p o s e ( ) ; 
 
 
 
 	 	 	 	 c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 	 i n t   s e c o n d T h r e a d I d   =   c . S e r v e r T h r e a d ; 
 
 	 	 	 	 K i l l C o n n e c t i o n ( c ) ; 
 
 	 	 	 	 c . C l o s e ( ) ; 
 
 	 	 	 	 A s s e r t . I s F a l s e ( t h r e a d I d   = =   s e c o n d T h r e a d I d ) ; 
 
 	 	 	 } 
 
 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 { 
 
 	 	 	 	 A s s e r t . F a i l ( e x . M e s s a g e ) ; 
 
 	 	 	 } 
 
 	 	 } 
 
 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   R e c l a i m B r o k e n C o n n e c t i o n ( ) 
 
 	 	 { 
 
 	 	 	 / /   n o w   c r e a t e   a   n e w   c o n n e c t i o n   s t r i n g   o n l y   a l l o w i n g   1   c o n n e c t i o n   i n   t h e   p o o l 
 
 	 	 	 s t r i n g   c o n n S t r   =   c o n n . C o n n e c t i o n S t r i n g   +   " ; m a x   p o o l   s i z e = 1 " ; 
 
 
 
 	 	 	 / /   n o w   u s e   u p   t h a t   c o n n e c t i o n 
 
 	 	 	 M y S q l C o n n e c t i o n   c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 c . O p e n ( ) ; 
 
 
 
 	 	 	 / /   n o w   a t t e m p t i n g   t o   o p e n   a   c o n n e c t i o n   s h o u l d   f a i l 
 
 	 	 	 t r y 
 
 	 	 	 { 
 
 	 	 	 	 M y S q l C o n n e c t i o n   c 2   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c 2 . O p e n ( ) ; 
 
 	 	 	 	 A s s e r t . F a i l ( " O p e n   a f t e r   u s i n g   u p   p o o l   s h o u l d   f a i l " ) ; 
 
 	 	 	 } 
 
 	 	 	 c a t c h   ( E x c e p t i o n )   {   } 
 
 
 
 	 	 	 / /   w e   n o w   k i l l   t h e   f i r s t   c o n n e c t i o n   t o   s i m u l a t e   a   s e r v e r   s t o p p a g e 
 
 	 	 	 b a s e . K i l l C o n n e c t i o n ( c ) ; 
 
 
 
 	 	 	 / /   n o w   w e   d o   s o m e t h i n g   o n   t h e   f i r s t   c o n n e c t i o n 
 
 	 	 	 t r y 
 
 	 	 	 { 
 
 	 	 	 	 c . C h a n g e D a t a b a s e ( " m y s q l " ) ; 
 
 	 	 	 	 A s s e r t . F a i l ( " T h i s   c h a n g e   d a t a b a s e   s h o u l d   n o t   w o r k " ) ; 
 
 	 	 	 } 
 
 	 	 	 c a t c h   ( E x c e p t i o n )   {   } 
 
 
 
 	 	 	 / /   O p e n i n g   a   c o n n e c t i o n   n o w   s h o u l d   w o r k 
 
 	 	 	 t r y 
 
 	 	 	 { 
 
 	 	 	 	 M y S q l C o n n e c t i o n   c 2   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c 2 . O p e n ( ) ; 
 
 	 	 	 	 c 2 . C l o s e ( ) ; 
 
 	 	 	 } 
 
 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 { 
 
 	 	 	 	 A s s e r t . F a i l ( e x . M e s s a g e ) ; 
 
 	 	 	 } 
 
 	 	 } 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   T e s t U s e r R e s e t ( ) 
 
 	 	 { 
 
 	 	 	 e x e c S Q L ( " S E T   @ t e s t v a r = ' 5 ' " ) ; 
 
 	 	 	 M y S q l C o m m a n d   c m d   =   n e w   M y S q l C o m m a n d ( " S E L E C T   @ t e s t v a r " ,   c o n n ) ; 
 
 	 	 	 o b j e c t   v a r   =   c m d . E x e c u t e S c a l a r ( ) ; 
 
 	 	 	 A s s e r t . A r e E q u a l ( " 5 " ,   v a r ) ; 
 
 	 	 	 c o n n . C l o s e ( ) ; 
 
 
 
 	 	 	 c o n n . O p e n ( ) ; 
 
 	 	 	 o b j e c t   v a r 2   =   c m d . E x e c u t e S c a l a r ( ) ; 
 
 	 	 	 A s s e r t . A r e E q u a l ( D B N u l l . V a l u e ,   v a r 2 ) ; 
 
 	 	 } 
 
 
 
 	 	 / / /   < s u m m a r y > 
 
 	 	 / / /   B u g   # 2 5 6 1 4   A f t e r   c o n n e c t i o n   i s   c l o s e d ,   a n d   o p e n e d   a g a i n   U T F - 8   c h a r a c t e r s   a r e   n o t   r e a d   w e l l   
 
 	 	 / / /   < / s u m m a r y > 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   U T F 8 A f t e r C l o s i n g ( ) 
 
 	 	 { 
 
 	 	 	 s t r i n g   o r i g i n a l V a l u e   =   " a
~`}" ; 
 
 
 
 	 	 	 e x e c S Q L ( " D R O P   T A B L E   I F   E X I S T S   t e s t " ) ; 
 
 	 	 	 e x e c S Q L ( " C R E A T E   T A B L E   t e s t   ( i d   i n t ( 1 1 )   N O T   N U L L ,   "   + 
 
 	 	 	 	 " v a l u e   v a r c h a r ( 1 0 0 )   N O T   N U L L ,   P R I M A R Y   K E Y     ( ` i d ` )   "   + 
 
 	 	 	 	 " )   E N G I N E = M y I S A M   D E F A U L T   C H A R S E T = u t f 8 " ) ; 
 
 
 
 	 	 	 s t r i n g   c o n n S t r   =   G e t C o n n e c t i o n S t r i n g ( t r u e )   +   " ; c h a r s e t = u t f 8 " ; 
 
 	 	 	 M y S q l C o n n e c t i o n   c o n   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 c o n . O p e n ( ) ; 
 
 
 
 	 	 	 t r y 
 
 	 	 	 { 
 
 	 	 	 	 M y S q l C o m m a n d   c m d   =   n e w   M y S q l C o m m a n d ( " I N S E R T   I N T O   t e s t   V A L U E S   ( 1 ,   ' a
~`}' ) " ,   c o n ) ; 
 
 	 	 	 	 c m d . E x e c u t e N o n Q u e r y ( ) ; 
 
 
 
 	 	 	 	 c m d   =   n e w   M y S q l C o m m a n d ( " S E L E C T   v a l u e   F R O M   t e s t   W H E R E   i d   =   1 " ,   c o n ) ; 
 
 	 	 	 	 s t r i n g   f i r s t S   =   c m d . E x e c u t e S c a l a r ( ) . T o S t r i n g ( ) ; 
 
 	 	 	 	 A s s e r t . A r e E q u a l ( o r i g i n a l V a l u e ,   f i r s t S ) ; 
 
 
 
 	 	 	 	 c o n . C l o s e ( ) ; 
 
 	 	 	 	 c o n . O p e n ( ) ; 
 
 
 
 	 	 	 	 / / D o e s   n o t   w o r k : 
 
 	 	 	 	 c m d   =   n e w   M y S q l C o m m a n d ( " S E L E C T   v a l u e   F R O M   t e s t   W H E R E   i d   =   1 " ,   c o n ) ; 
 
 	 	 	 	 s t r i n g   s e c o n d S   =   c m d . E x e c u t e S c a l a r ( ) . T o S t r i n g ( ) ; 
 
 
 
 	 	 	 	 c o n . C l o s e ( ) ; 
 
 	 	 	 	 A s s e r t . A r e E q u a l ( f i r s t S ,   s e c o n d S ) ; 
 
 	 	 	 } 
 
 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 { 
 
 	 	 	 	 A s s e r t . F a i l ( e x . M e s s a g e ) ; 
 
 	 	 	 } 
 
 	 	 } 
 
 
 
 # i f   ! C F 
 
 
 
 	 	 p r i v a t e   v o i d   P o o l i n g W o r k e r ( o b j e c t   c n ) 
 
 	 	 { 
 
 	 	 	 M y S q l C o n n e c t i o n   c o n n   =   ( c n   a s   M y S q l C o n n e c t i o n ) ; 
 
 
 
 	 	 	 T h r e a d . S l e e p ( 5 0 0 0 ) ; 
 
 	 	 	 c o n n . C l o s e ( ) ; 
 
 	 	 } 
 
 
 
 	 	 / / /   < s u m m a r y > 
 
 	 	 / / /   B u g   # 2 4 3 7 3   H i g h   C P U   u t i l i z a t i o n   w h e n   n o   i d l e   c o n n e c t i o n   
 
 	 	 / / /   < / s u m m a r y > 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   M u l t i p l e T h r e a d s ( ) 
 
 	 	 { 
 
 	 	 	 s t r i n g   c o n n S t r   =   G e t C o n n e c t i o n S t r i n g ( t r u e )   +   " ; m a x   p o o l   s i z e = 1 " ; 
 
 	 	 	 M y S q l C o n n e c t i o n   c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 c . O p e n ( ) ; 
 
 
 
 	 	 	 P a r a m e t e r i z e d T h r e a d S t a r t   t s   =   n e w   P a r a m e t e r i z e d T h r e a d S t a r t ( P o o l i n g W o r k e r ) ; 
 
 	 	 	 T h r e a d   t   =   n e w   T h r e a d ( t s ) ; 
 
 	 	 	 t . S t a r t ( c ) ; 
 
 
 
 	 	 	 t r y 
 
 	 	 	 { 
 
 	 	 	 	 M y S q l C o n n e c t i o n   c 2   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c 2 . O p e n ( ) ; 
 
 	 	 	 	 c 2 . C l o s e ( ) ; 
 
 	 	 	 } 
 
 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 { 
 
 	 	 	 	 A s s e r t . F a i l ( e x . M e s s a g e ) ; 
 
 	 	 	 } 
 
 	 	 } 
 
 
 
 # e n d i f 
 
 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   N e w T e s t ( ) 
 
 	 	 { 
 
 	 	 	 i f   ( v e r s i o n   <   n e w   V e r s i o n ( 5 ,   0 ) )   r e t u r n ; 
 
 
 
 	 	 	 e x e c S Q L ( " D R O P   T A B L E   I F   E X I S T S   t e s t " ) ; 
 
 	 	 	 e x e c S Q L ( " D R O P   P R O C E D U R E   I F   E X I S T S   s p T e s t " ) ; 
 
 	 	 	 e x e c S Q L ( " C R E A T E   T A B L E   t e s t   ( i d   I N T ,   n a m e   V A R C H A R ( 5 0 ) ) " ) ; 
 
 	 	 	 e x e c S Q L ( " C R E A T E   P R O C E D U R E   s p T e s t ( t h e i d   I N T )   B E G I N   S E L E C T   *   F R O M   t e s t   W H E R E   i d = t h e i d ;   E N D " ) ; 
 
 	 	 	 e x e c S Q L ( " I N S E R T   I N T O   t e s t   V A L U E S   ( 1 ,   ' F i r s t ' ) " ) ; 
 
 	 	 	 e x e c S Q L ( " I N S E R T   I N T O   t e s t   V A L U E S   ( 2 ,   ' S e c o n d ' ) " ) ; 
 
 	 	 	 e x e c S Q L ( " I N S E R T   I N T O   t e s t   V A L U E S   ( 3 ,   ' T h i r d ' ) " ) ; 
 
 	 	 	 e x e c S Q L ( " I N S E R T   I N T O   t e s t   V A L U E S   ( 4 ,   ' F o u r t h ' ) " ) ; 
 
 
 
 	 	 	 s t r i n g   c o n n S t r   =   G e t C o n n e c t i o n S t r i n g ( t r u e ) ; 
 
 
 
 	 	 	 f o r   ( i n t   i   =   1 ;   i   <   5 ;   i + + ) 
 
 	 	 	 { 
 
 	 	 	 	 u s i n g   ( M y S q l C o n n e c t i o n   c o n   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ) 
 
 	 	 	 	 { 
 
 	 	 	 	 	 t r y 
 
 	 	 	 	 	 { 
 
 	 	 	 	 	 	 c o n . O p e n ( ) ; 
 
 	 	 	 	 	 	 M y S q l C o m m a n d   r e c c m d   =   n e w   M y S q l C o m m a n d ( " s p T e s t " ,   c o n ) ; 
 
                                                 r e c c m d . C o m m a n d T i m e o u t   =   0 ; 
 
 	 	 	 	 	 	 r e c c m d . C o m m a n d T y p e   =   C o m m a n d T y p e . S t o r e d P r o c e d u r e ; 
 
 	 	 	 	 	 	 M y S q l P a r a m e t e r   p a r   =   n e w   M y S q l P a r a m e t e r ( " t h e i d " ,   M y S q l D b T y p e . S t r i n g ) ; 
 
 	 	 	 	 	 	 p a r . V a l u e   =   i ; 
 
 	 	 	 	 	 	 r e c c m d . P a r a m e t e r s . A d d ( p a r ) ; 
 
 	 	 	 	 	 	 u s i n g   ( M y S q l D a t a R e a d e r   r e c d r   =   r e c c m d . E x e c u t e R e a d e r ( ) ) 
 
 	 	 	 	 	 	 { 
 
 	 	 	 	 	 	 	 i f   ( r e c d r . R e a d ( ) ) 
 
 	 	 	 	 	 	 	 { 
 
 	 	 	 	 	 	 	 	 i n t   x   =   r e c d r . G e t O r d i n a l ( " n a m e " ) ; 
 
 	 	 	 	 	 	 	 	 A s s e r t . A r e E q u a l ( 1 ,   x ) ; 
 
 	 	 	 	 	 	 	 } 
 
 	 	 	 	 	 	 } 
 
 	 	 	 	 	 } 
 
 	 	 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 	 	 { 
 
 	 	 	 	 	 	 A s s e r t . F a i l ( e x . M e s s a g e ) ; 
 
 	 	 	 	 	 } 
 
 	 	 	 	 } 
 
 	 	 	 } 
 
 	 	 } 
 
 
 
 	 	 / / /   < s u m m a r y > 
 
 	 	 / / /   B u g   # 2 9 4 0 9     	 B u g   o n   O p e n   C o n n e c t i o n   w i t h   p o o l i n g = t r u e   t o   a   M Y S Q L   S e r v e r   t h a t   i s   s h u t d o w n 
 
 	 	 / / /   < / s u m m a r y > 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   C o n n e c t A f t e r M a x P o o l S i z e T i m e o u t s ( ) 
 
 	 	 { 
 
 	 	 	 / / T O D O :   r e f a c t o r   t e s t   s u i t e   t o   s u p p o r t   s t a r t i n g / s t o p p i n g   s e r v i c e s 
 
 	 	 	 / *                         s t r i n g   c o n n S t r   =   " s e r v e r = l o c a l h o s t ; u i d = r o o t ; d a t a b a s e = t e s t ; p o o l i n g = t r u e ; c o n n e c t   t i m e o u t = 6 ;   m a x   p o o l   s i z e   =   6 " ; 
 
 	 	 	 	 	 	 M y S q l C o n n e c t i o n   c   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   6 ;   i + + ) 
 
 	 	 	 	 	 	 { 
 
 	 	 	 	 	 	 	 t r y 
 
 	 	 	 	 	 	 	 { 
 
 	 	 	 	 	 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 	 	 	 	 } 
 
 	 	 	 	 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 	 	 	 	 { 
 
 	 	 	 	 	 	 	 } 
 
 	 	 	 	 	 	 } 
 
 	 	 	 	 	 	 c . O p e n ( ) ; 
 
 	 	 	 	 	 	 c . C l o s e ( ) ; * / 
 
 	 	 } 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   C l e a r P o o l ( ) 
 
 	 	 { 
 
 	 	 	 s t r i n g   c o n n S t r   =   G e t C o n n e c t i o n S t r i n g ( t r u e )   +   " ;   m i n   p o o l   s i z e = 1 0 " ; 
 
 	 	 	 M y S q l C o n n e c t i o n [ ]   c o n n e c t i o n s   =   n e w   M y S q l C o n n e c t i o n [ 1 0 ] ; 
 
 	 	 	 c o n n e c t i o n s [ 0 ]   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 c o n n e c t i o n s [ 0 ] . O p e n ( ) ; 
 
 
 
                         s t r i n g   a s s e m b l y N a m e   =   t y p e o f ( M y S q l C o n n e c t i o n ) . A s s e m b l y . F u l l N a m e ; 
 
                         s t r i n g   p m N a m e   =   S t r i n g . F o r m a t ( " M y S q l . D a t a . M y S q l C l i e n t . M y S q l P o o l M a n a g e r ,   { 0 } " ,   a s s e m b l y N a m e ) ; 
 
 
 
                         T y p e   p o o l M a n a g e r   =   T y p e . G e t T y p e ( p m N a m e ,   f a l s e ) ; 
 
                         F i e l d I n f o   p o o l M a n a g e r H a s h T a b l e   =   p o o l M a n a g e r . G e t F i e l d ( " p o o l s " , 
 
                                 B i n d i n g F l a g s . N o n P u b l i c   |   B i n d i n g F l a g s . S t a t i c   |   B i n d i n g F l a g s . I n s t a n c e ) ; 
 
                         H a s h t a b l e   p o o l H a s h   =   ( H a s h t a b l e ) p o o l M a n a g e r H a s h T a b l e . G e t V a l u e ( n u l l ) ; 
 
                         F i e l d I n f o   c l e a r i n g P o o l s F I   =   p o o l M a n a g e r . G e t F i e l d ( " c l e a r i n g P o o l s " , 
 
                                 B i n d i n g F l a g s . N o n P u b l i c   |   B i n d i n g F l a g s . S t a t i c   |   B i n d i n g F l a g s . I n s t a n c e ) ; 
 
                         I C o l l e c t i o n   c l e a r i n g P o o l s   =   ( I C o l l e c t i o n ) c l e a r i n g P o o l s F I . G e t V a l u e ( n u l l ) ; 
 
 
 
                         / /   n o w   w e   n e e d   t o   i n v e s t i g a t e 
 
                         s t r i n g   p o o l N a m e   =   S t r i n g . F o r m a t ( " M y S q l . D a t a . M y S q l C l i e n t . M y S q l P o o l ,   { 0 } " ,   a s s e m b l y N a m e ) ; 
 
                         T y p e   p o o l T y p e   =   T y p e . G e t T y p e ( p o o l N a m e ,   f a l s e ) ; 
 
                         
 
                         F i e l d I n f o   i n U s e P o o l   =   p o o l T y p e . G e t F i e l d ( " i n U s e P o o l " ,   B i n d i n g F l a g s . N o n P u b l i c   |   B i n d i n g F l a g s . I n s t a n c e ) ; 
 
                         I C o l l e c t i o n   i n U s e L i s t   =   ( I C o l l e c t i o n ) i n U s e P o o l . G e t V a l u e ( p o o l H a s h [ c o n n S t r ] ) ; 
 
                         A s s e r t . A r e E q u a l ( 1 ,   i n U s e L i s t . C o u n t ) ; 
 
 
 
                         F i e l d I n f o   i d l e P o o l   =   p o o l T y p e . G e t F i e l d ( " i d l e P o o l " ,   B i n d i n g F l a g s . N o n P u b l i c   |   B i n d i n g F l a g s . I n s t a n c e ) ; 
 
                         I C o l l e c t i o n   i d l e L i s t   =   ( I C o l l e c t i o n ) i d l e P o o l . G e t V a l u e ( p o o l H a s h [ c o n n S t r ] ) ; 
 
                         A s s e r t . A r e E q u a l ( 9 ,   i d l e L i s t . C o u n t ) ; 
 
 
 
 	 	 	 / /   n o w   o p e n   4   m o r e   o f   t h e s e .     N o w   w e   s h o u d l   h a v e   5   o p e n   a n d   f i v e 
 
 	 	 	 / /   s t i l l   i n   t h e   p o o l 
 
 	 	 	 f o r   ( i n t   i   =   1 ;   i   <   5 ;   i + + ) 
 
 	 	 	 { 
 
 	 	 	 	 c o n n e c t i o n s [ i ]   =   n e w   M y S q l C o n n e c t i o n ( c o n n S t r ) ; 
 
 	 	 	 	 c o n n e c t i o n s [ i ] . O p e n ( ) ; 
 
 	 	 	 } 
 
 
 
                         A s s e r t . A r e E q u a l ( 5 ,   i n U s e L i s t . C o u n t ) ; 
 
                         A s s e r t . A r e E q u a l ( 5 ,   i d l e L i s t . C o u n t ) ; 
 
 
 
                         A s s e r t . A r e E q u a l ( 0 ,   c l e a r i n g P o o l s . C o u n t ) ; 
 
 	 	 	 / /   n o w   t e l l   t h i s   c o n n e c t i o n   t o   c l e a r   i t s   p o o l 
 
 	 	 	 M y S q l C o n n e c t i o n . C l e a r P o o l ( c o n n e c t i o n s [ 0 ] ) ; 
 
                         A s s e r t . A r e E q u a l ( 1 ,   c l e a r i n g P o o l s . C o u n t ) ; 
 
 	 	 	 A s s e r t . A r e E q u a l ( 0 ,   i d l e L i s t . C o u n t ) ; 
 
 
 
 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   5 ;   i + + ) 
 
 	 	 	 	 c o n n e c t i o n s [ i ] . C l o s e ( ) ; 
 
                         A s s e r t . A r e E q u a l ( 0 ,   c l e a r i n g P o o l s . C o u n t ) ; 
 
 	 	 } 
 
 
 
 	 	 [ T e s t ] 
 
 	 	 p u b l i c   v o i d   T e s t B a d C o n n e c t i o n s ( ) 
 
 	 	 { 
 
 	 	 	 M y S q l C o n n e c t i o n S t r i n g B u i l d e r   b u i l d e r   =   n e w 
 
 	 	 	 M y S q l C o n n e c t i o n S t r i n g B u i l d e r ( ) ; 
 
 
 
 	 	 	 b u i l d e r . P o o l i n g   =   t r u e ; 
 
 	 	 	 b u i l d e r . S e r v e r   =   " x x x x x x x x " ;   / /   o n e   t h a t   d e f i n i t e l y   d o e s   n o t   e x i s t . 
 
 	 	 	 b u i l d e r . U s e r I D   =   " w h o e v e r " ; 
 
 	 	 	 b u i l d e r . P a s s w o r d   =   " w h a t e v e r " ; 
 
 
 
 	 	 	 i n t   n u m b e r O f C o n n e c t i o n s   =   1 ; 
 
 
 
 	 	 	 f o r   ( i n t   i   =   0 ;   i   <   n u m b e r O f C o n n e c t i o n s ;   + + i ) 
 
 	 	 	 { 
 
 	 	 	 	 u s i n g   ( M y S q l C o n n e c t i o n   c o n n e c t i o n   =   n e w   M y S q l C o n n e c t i o n ( b u i l d e r . C o n n e c t i o n S t r i n g ) ) 
 
 	 	 	 	 { 
 
 	 	 	 	 	 t r y 
 
 	 	 	 	 	 { 
 
 	 	 	 	 	 	 c o n n e c t i o n . O p e n ( ) ; 
 
 	 	 	 	 	 	 A s s e r t . F a i l ( " C o n n e c t i o n   s h o u l d   t h r o w   a n   e x c e p t i o n . " ) ; 
 
 	 	 	 	 	 } 
 
 	 	 	 	 	 c a t c h   ( E x c e p t i o n   e x ) 
 
 	 	 	 	 	 { 
 
 	 	 	 	 	 } 
 
 	 	 	 	 } 
 
 	 	 	 	 T h r e a d . S l e e p ( 5 0 ) ; 
 
 	 	 	 } 
 
 	 	 	 M y S q l C o n n e c t i o n . C l e a r A l l P o o l s ( ) ; 
 
 	 	 } 
 
 	 } 
 
 } 
 
 